import React, { useEffect, useState } from 'react'
import { useTranslation } from 'react-i18next'
import { MenuItem, Select, SelectChangeEvent } from '@mui/material'


function LanguageSelector() {
  const { i18n, t } = useTranslation('common')
  const [selectedLanguage, setSelectedLanguage] = useState('en')

  const languageOptions = new Map([
    ['en', 'English'],
    ['nn', 'Norsk nynorsk'],
    ['nb', 'Norsk bokmål'],
  ])

  useEffect(() => {
    setSelectedLanguage(i18n.language)
  })

  const handleLanguageChange = (event: SelectChangeEvent) => {
    if (event.target) {
      i18n.changeLanguage(event.target.value)
    }
  }

  return (
    <Select labelId='language-select'
            label={t('header.selectLanguage')}
            sx={{ color: 'white' }}
            variant='standard'
            value={selectedLanguage}
            onChange={handleLanguageChange}
    >
      {
        Array.from(languageOptions.entries()).map((entry) => (<MenuItem value={entry[0]}>{entry[1]}</MenuItem>))
      }
    </Select>
  )
}

export default LanguageSelector