import React, { useState } from 'react'

import { UserContext } from 'contexts'

type UserProviderProps = {
  children: React.ReactNode
}

function UserProvider(props: UserProviderProps) {
  const { children } = props
  const [user, setUser] = useState({
    auth: false,
    first_name: '',
    last_name: '',
  })
  const [fetching, setFetching] = useState(false)

  const getUserInfo = async () => {
    try {
      const response = await fetch('/api/ui/v1/userinfo/')
      const data = await response.json()

      if (response.ok) {
        setUser({
          auth: true,
          first_name: data.first_name,
          last_name: data.last_name,
        })
      }
    } catch (error) {
      // Do nothing
    }
    setFetching(false)
  }

  const fetchUserInfo = () => {
    if (!user.auth && !fetching) {
      setFetching(true)
      getUserInfo()
    }
  }

  const clearUserInfo = () => {
    setUser({ auth: false, first_name: '', last_name: '' })
  }

  return (
    <UserContext.Provider value={{ user, fetchUserInfo, clearUserInfo }}>
      {children}
    </UserContext.Provider>
  )
}

export default UserProvider
