import React from 'react'
import { useTranslation } from 'react-i18next'
import { styled } from '@mui/material/styles'

import {
  appStagingWarning,
  appTechnicalSupportLink,
  reponsibleOrganization,
  responsibleOrganizationLink,
} from 'appConfig'
import Link from 'components/link'

const FooterWrapper = styled('footer')(({ theme }) => ({
  background: theme.greg.footerBackgroundColor,
  height: 'fit-content',
  padding: '0rem 6.5rem',
  marginTop: 'auto',
}))

const FooterSection = styled('section')({
  header: {
    marginBottom: '0.5rem',
    fontSize: '1.5rem',
  },

  paddingLeft: '1rem',
})

const FooterSectionContent = styled('div')({
  fontSize: '1rem',
  paddingLeft: '0.3rem',
})

const ContentContainer = styled('div')(({ theme }) => ({
  width: 'fit-content',
  color: theme.greg.footerTextColor,
  display: 'flex',
  flexWrap: 'nowrap',
  justifyContent: 'space-between',
  margin: 'auto',
  padding: '1rem 1rem 1rem 0',
}))

const Footer: React.FunctionComponent = () => {
  const { t } = useTranslation(['common', 'footer'])

  return (
    <>
      <FooterWrapper>
        <ContentContainer>
          <FooterSection>
            <header>{t('footer:contactSectionHeader')}</header>
            <FooterSectionContent>
              <Link
                external
                to={appTechnicalSupportLink}
                inheritColor
                underline
              >
                {t('footer:contactHelp')}
              </Link>
            </FooterSectionContent>
          </FooterSection>

          <FooterSection>
            <header>{t('footer:responsibleOrganizationHeader')}</header>
            <FooterSectionContent>
              <Link
                external
                to={responsibleOrganizationLink}
                inheritColor
                underline
              >
                {reponsibleOrganization}
              </Link>
            </FooterSectionContent>
          </FooterSection>
        </ContentContainer>
      </FooterWrapper>
      {appStagingWarning && <div className="alert">{t('staging')}</div>}
    </>
  )
}

export default Footer
