import React from 'react'
import { Link } from 'react-router-dom'
import { useTranslation } from 'react-i18next'
import { styled } from '@mui/material/styles'
import Box from '@mui/material/Box'

import LogoBar from 'components/logobars/LogoBar'
import LanguageSelector from 'components/languageselector'
import UserInfo from 'routes/components/userInfo'

const MainWrapper = styled('div')(({ theme }) => ({
  color: theme.greg.h1TextColor,
  backgroundColor: theme.greg.headerBackgroundColor,

  a: {
    textDecoration: 'none',

    '&:hover, &:focus': {
      textDecoration: 'underline',
    },
  },
}))

const Main = styled('div')(({ theme }) => ({
  display: 'flex',
  justifyContent: 'space-between',
  margin: '0 auto',
  maxWidth: theme.greg.appMaxWidth,
  padding: '0.5rem 6.5rem 1rem 6.5rem',
}))

const Menu = styled('ul')({
  listStyleType: 'none',
})

const MenuItem = styled('div')({
  fontSize: '1rem',
  display: 'inline',
})

const Header = () => {
  const { t } = useTranslation('common')

  return (
    <header>
      <LogoBar />
      <MainWrapper>
        <Main>
          <Box
            sx={{
              display: 'flex',
              flexDirection: 'column',
              paddingLeft: '3rem',
            }}
          >
            <Link to="/">
              <Box
                sx={{
                  color: 'white',
                  whiteSpace: 'nowrap',
                  textDecoration: 'none',
                  fontSize: '2rem',
                  fontWeight: 'bold',
                }}
              >
                {t('header.applicationTitle')}
              </Box>
            </Link>
            <Box sx={{ fontSize: '1rem' }}>
              {t('header.applicationDescription')}
            </Box>
          </Box>
          <Menu>
            <MenuItem>
              <UserInfo />
            </MenuItem>
            <MenuItem>
              <LanguageSelector />
            </MenuItem>
          </Menu>
        </Main>
      </MainWrapper>
    </header>
  )
}

export default Header
